#include "include/manus.h"
#include "include/tools/terminate.h"
#include "include/tools/python_execute.h"
#include "include/tools/planning.h"
#include <iostream>
#include <memory>

namespace openmanus {

Manus::Manus(const std::string& config_file)
    : ToolCallAgent("Manus", "一个通用的智能助手，可以使用多种工具解决各种任务", config_file) {
    // 初始化Manus代理
    initialize();
}

void Manus::initialize() {
    // 系统提示和下一步提示已经在ToolCallAgent构造函数中从配置文件读取
    
    // 添加Manus特定的工具
    addManusTools();
}

void Manus::addManusTools() {
    // 添加终止工具
    available_tools_->addTool(std::make_unique<Terminate>());
    
    // 添加规划工具
    available_tools_->addTool(std::make_unique<Planning>());
    
    // 根据配置决定是否添加Python执行工具
    if (config_.getBool("tools", "enable_python_execute", true)) {
        available_tools_->addTool(std::make_unique<PythonExecute>());
    }
    
    // 在这里添加其他Manus特定的工具
    // 根据配置决定是否添加其他工具
    if (config_.getBool("tools", "enable_google_search", false)) {
        // available_tools_->addTool(std::make_unique<GoogleSearch>());
        std::cout << "Google搜索工具尚未实现" << std::endl;
    }
    
    if (config_.getBool("tools", "enable_browser_use", false)) {
        // available_tools_->addTool(std::make_unique<BrowserUseTool>());
        std::cout << "浏览器使用工具尚未实现" << std::endl;
    }
    
    if (config_.getBool("tools", "enable_file_saver", false)) {
        // available_tools_->addTool(std::make_unique<FileSaver>());
        std::cout << "文件保存工具尚未实现" << std::endl;
    }
    
    std::cout << "添加Manus特定的工具..." << std::endl;
}

} // namespace openmanus 